<?php

use QUI\ERP\Payments\Paymill\PaymillException;
use QUI\ERP\Payments\Stripe\PaymentMethods\Recurring\BillingPlans;
use QUI\Utils\Security\Orthos;
use QUI\Utils\Grid;
use QUI\ERP\Payments\Stripe\Provider;

/**
 * Get list of Stripe Billing Plans
 *
 * @param array $searchParams - Grid search params
 * @return array
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_payment-stripe_ajax_backend_settings_getBillingPlans',
    function ($searchParams) {
        $searchParams = Orthos::clearArray(json_decode($searchParams, true));
        $startId      = null;
        $perPage      = null;

        if (!empty($searchParams['startId'])) {
            $startId = Orthos::clear($searchParams['startId']);
        }

        if (!empty($searchParams['perPage'])) {
            $perPage = (int)$searchParams['perPage'];
        }

        $Result       = BillingPlans::getBillingPlanList($startId, $perPage);
        $billingPlans = [];

        foreach ($Result->autoPagingIterator() as $BillingPlan) {
            $billingPlans[] = $BillingPlan->toArray();
        }

        $count = 0;

        if (!empty($billingPlans)) {
            $count = \count($billingPlans);

            if ($Result->has_more) {
                $count++;
            }
        }

        $isSandbox = Provider::isSandbox();

        foreach ($billingPlans as $k => $billingPlan) {
            $billingPlans[$k]['isSandbox'] = $isSandbox;
            $billingPlans[$k]['created']   = date('Y-m-d H:i:s', $billingPlan['created']);
        }

        $Grid = new Grid($searchParams);
        return $Grid->parseResult($billingPlans, $count);
    },
    ['searchParams'],
    ['Permission::checkAdminUser', 'quiqqer.payments.stripe.billing_plans.view']
);
