<?php

namespace QUI\ERP\Payments\Stripe;

use QUI;
use QUI\ERP\Accounting\Payments\Exceptions\PaymentCanNotBeUsed as PaymentCanNotBeUsedException;
use QUI\ERP\Accounting\Payments\Types\Payment;
use QUI\ERP\Order\OrderInterface;
use QUI\Package\Package;

class Events
{
    /**
     * quiqqer/quiqqer: onPackageInstallAfter
     *
     * @param Package $Package
     * @return void
     */
    public static function onPackageInstallAfter(Package $Package)
    {
        if ($Package->getName() !== 'quiqqer/payment-stripe') {
            return;
        }

        try {
            Provider::setupDefaultPaymentMethods();
        } catch (\Exception $Exception) {
            QUI\System\Log::addError($Exception->getMessage());
        }
    }

    /**
     * quiqqer/payments: onPaymentsCanUsedInOrder
     *
     * Check if a payment type can be used in the current browser
     *
     * @param Payment $Payment
     * @param OrderInterface $Order
     * @throws QUI\ERP\Accounting\Payments\Exceptions\PaymentCanNotBeUsed
     */
    public static function onPaymentsCanUsedInOrder(Payment $Payment, OrderInterface $Order)
    {
        try {
            $PaymentType = $Payment->getPaymentType();
        } catch (\Exception $Exception) {
            QUI\System\Log::writeException($Exception);
            return;
        }

        if (!($PaymentType instanceof QUI\ERP\Payments\Stripe\PaymentMethods\AbstractBrowserPay)
            && !($PaymentType instanceof QUI\ERP\Payments\Stripe\PaymentMethods\Recurring\AbstractRecurringBrowserPay)) {
            return;
        }

        $B = new \Browser();

        if (!$B->isMobile()) {
            throw new PaymentCanNotBeUsedException();
        }

        if (!\in_array($B->getBrowser(), $PaymentType->getBrowserTypes())) {
            throw new PaymentCanNotBeUsedException();
        }
    }
}
