<?php

namespace QUI\ERP\Payments\Stripe\PaymentMethods;

use QUI;
use QUI\ERP\Accounting\Invoice\Invoice;
use QUI\ERP\Accounting\Invoice\InvoiceView;
use QUI\ERP\Accounting\Payments\Payments;

/**
 * Class MicrosoftPay
 *
 * Payment via Microsoft Pay (former Microsoft Wallet)
 */
class MicrosoftPay extends AbstractBrowserPay
{
    /**
     * @return string
     */
    public function getTitle()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.MicrosoftPay.title');
    }

    /**
     * @return string
     */
    public function getDescription()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.MicrosoftPay.description');
    }

    /**
     * Get title for frontend
     *
     * @return string
     */
    public function getFrontendTitle()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.MicrosoftPay.title');
    }

    /**
     * Get description for frontend
     *
     * @return string
     */
    public function getFrontendDescription()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.MicrosoftPay.description');
    }

    /**
     * Get title for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepTitle()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.PaymentStep.title.MicrosoftPay');
    }

    /**
     * Get description step for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepInfo()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.PaymentStep.info.MicrosoftPay');
    }

    /**
     * Get type of Browser this BrowserPay works with
     *
     * @return string[]
     */
    public function getBrowserTypes()
    {
        return [
            \Browser::BROWSER_EDGE
        ];
    }

    /**
     * Return the payment icon (the URL path)
     * Can be overwritten
     *
     * @return string
     */
    public function getIcon()
    {
        return Payments::getInstance()->getHost().
               URL_OPT_DIR.
               'quiqqer/payment-stripe/bin/images/Payment_MicrosoftPay.png';
    }

    /**
     * Return the extra text for the invoice
     *
     * @param Invoice|InvoiceView $Invoice
     * @return mixed
     */
    public function getInvoiceInformationText($Invoice)
    {
        try {
            return $Invoice->getCustomer()->getLocale()->get(
                'quiqqer/payment-stripe',
                'additional_invoice_text.MicrosoftPay'
            );
        } catch (\Exception $Exception) {
            QUI\System\Log::writeException($Exception);
            return '';
        }
    }
}
